Name:           mailfront-plugin-check-helo
Summary:        A mailfront plugin to provide an ability to reject, defer or add it's helo name checking results to message header
Version:        0.08
Release:        1%{?dist}
License:        GPL
Group:          Utilities/System
Source:         http://choon.net/opensource/mailfront-plugin-check-helo-%{version}.tar.bz2
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildRequires:  gcc >= 3.4.6, make, bglibs-devel >= 2.04, mailfront-devel >= 2.22
Requires:       bglibs >= 2.04, mailfront >= 2.22, ucspi-tcp >= 0.88
URL:            http://choon.net/mailfront-plugin-check-helo.php

%description
Plugin: check-helo

A mailfront plugin to provide an ability to reject, defer or add it's HELO
name checking results to message header.

Reference:
http://www.linuxmagic.com/best_practices/valid_helo_domain.html

This plugin checks sequence:

(1).  If $HELO_CHECK_SKIP is set, this plugin will be skipped.

(2).  If $RELAYCLIENT is set, add to message header and skip the remaining
      checks.  Example of message header added:

      X-HELO-Check-Result: SKIPPED: $RELAYCLIENT is set for 1.2.3.4

(3).  If sender is authenticated, add to message header and skip the
      remaining checks.  Example of message header added:

      X-HELO-Check-Result: SKIPPED: authenticated user from 1.2.3.4

(4).  If $RBLSMTPD is set and empty, add to message header and skip the
      remaining checks.

(5).  Check HELO name for the following:
      (5.1).  Cannot starts with ".", "[" and "-"
      (5.2).  Cannot ends with ".", "]" and "-"
      (5.3).  Must have at least a "." (dot)
      (5.4).  Cannot have any of the following characters besides TAB
              and SPACE:
                  ~!@#$%^&*()_+={}[]:;"'<>,?/|
      (5.5).  Cannot use a valid IPv4 or IPv6 address
      NOTE: If any of the above checks failed, the remaining checks will
      be skipped.
      (Refer to $HELO_CHECK_ADD_HEADER, $HELO_CHECK_DEFER and
      $HELO_CHECK_REJECT)
      Example of message header added:

      X-HELO-Check-Result: FAILED
      X-HELO-Check-Summary: '.' found in last character of HELO name sender_set_HELO_name

(6).  Do a DNS A record or AAAA record lookup for HELO name according to
      ${PROTO}REMOTEIP. If the DNS lookup failed will skip all remaining checks
      and add to message header or defer or reject.
      (Refer to $HELO_CHECK_ADD_HEADER, $HELO_CHECK_DEFER and
      $HELO_CHECK_REJECT)

      If $HELO_CHECK_ADD_HEADER is set will add the check to message header.
      ($HELO_CHECK_REJECT and $HELO_CHECK_DEFER not set)
      Example of message header added:

      X-HELO-Check-Result: FAILED
      X-HELO-Check-Summary: HELO name sender_set_HELO_name DNS A record lookup failed

(7).  If $HELO_CHECK_MATCH_IP is set, this plugin will check whether
      ${PROTO}REMOTEIP and HELO name IP are the same. If this check failed will
      skip all remaining checks and add to message header or defer or reject
      accordingly.

      If $HELO_CHECK_ADD_HEADER is set will add the check to message header.
      ($HELO_CHECK_REJECT and $HELO_CHECK_DEFER not set)
      Example of message header added:

      X-HELO-Check-Result: FAILED
      X-HELO-Check-Summary: Sorry, your HELO name IPv4 doesn't resolve to match your IPv4.

(8).  If $HELO_CHECK_MATCH_IP_CLASS is set, this plugin will check whether
      ${PROTO}REMOTEIP and HELO name IP are in the same IP class. If this check
      failed will skip all remaining checks and add to message header or defer
      or reject accordingly.

      If $HELO_CHECK_ADD_HEADER is set will add the check to message header.
      ($HELO_CHECK_REJECT and $HELO_CHECK_DEFER not set)
      Example of message header added:

      X-HELO-Check-Result: FAILED
      X-HELO-Check-Summary: Sorry, your HELO name IPv4 doesn't resolve to match your IPv4 class.

(9).  If all checks pass and $HELO_CHECK_ADD_HEADER is set will add the check
      to message header.

      Example of message header added:

      X-HELO-Check-Result: PASSED
      X-HELO-Check-Summary: HELO name sender_HELO_name from REMOTEIP 1.2.3.4 is valid.

(10). If $HELO_CHECK_VERBOSE is set, this plugin will log all its checking
      to stderr.


%prep
%setup -q
# for bglibs
# conf-bgincs default is /usr/local/bglibs/include
echo %{_includedir}/bglibs > conf-bgincs
# conf-bglibs default is /usr/local/bglibs/lib
echo %{_libdir}/bglibs > conf-bglibs
# conf-ld default is gcc -s -L/usr/local/lib
echo "gcc -Wall -g -O2 -s -rdynamic" >conf-ld
# conf-mailfrontincs default is /usr/local/include/mailfront
echo %{_includedir}/mailfront > conf-mailfrontincs
# conf-modules default is /usr/local/lib/mailfront
echo %{_libdir}/mailfront > conf-modules
echo "gcc %{optflags}" >conf-cc
# conf-ccso default is gcc -W -Wall -Wshadow -O -g -I/usr/local/include -fPIC -shared
echo "gcc %{optflags} -fPIC -shared" >conf-ccso
echo "gcc -s -rdynamic" >conf-ld
#echo %{_bindir} >conf-bin
echo %{_libdir}/mailfront >conf-modules
echo %{_includedir} >conf-include

%build
make

%install
rm -fr %{buildroot}
mkdir -p %{buildroot}/%{_libdir}/mailfront
install -m0755 plugin-check-helo.so %{buildroot}/%{_libdir}/mailfront/

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root)
%doc README COPYING CHANGES
#%{_bindir}/*
%{_libdir}/mailfront/plugin-check-helo.so

%changelog
* Tue Mar 19 2019 Giam Teck Choon <choonrpms@choon.net> - 0.08-1
- Update to version 0.08
- Remove BuildRequires libowfat-devel
- Remove Requires libowfat-shared
- Update BuildRequires bglibs-devel >= 2.04
- Update BuildRequires mailfront-devel >= 2.22
- Update Requires bglibs >= 2.04
- Update Requires mailfront >= 2.22

* Thu Aug 08 2013 Giam Teck Choon <choonrpms@choon.net> - 0.07-1
- Add IPv6 support

* Sun Jun 23 2013 Giam Teck Choon <choonrpms@choon.net> - 0.06-1
- Add new define elogerr function and simplified those printing to stderr log
- Change coding style to 2 spacing instead of using TAB as there is no reason
  to follow kernel coding style
- Add $HELO_CHECK_PTR_MATCH support
- Add $HELO_CHECK_ADD_HEADER support
- Update README and plugin-check-helo.html

* Fri Jun 07 2013 Giam Teck Choon <choonrpms@choon.net> - 0.05-1
- Change response numbers for defer (451) and reject (553) to follow what we
  used for rblsmtpd instead
- Add support to skip this plugin if $RBLSMTPD is set and empty
- Various bugs fixed mainly due to str_free() those not suppose to for static
  str declarations
- Rename declaration of str errormsg to str estr

* Fri May 31 2013 Giam Teck Choon <choonrpms@choon.net> - 0.04-1
- Fix typo in resp.number to 421 instead of 451 if $HELO_CHECK_DEFER is set
- Change return value in check_hostname function to actual ret value instead
  of 0
- If ret == EAI_MEMORY return Out of Memory error in response in function
  response *sender besides int outofmemory greater than 0
- If resp.number is greater than 0 and ret == EAI_NONAME, defer or reject
  accordingly in function response *sender otherwise defer the mail for
  remote MTA to retry later as failsafe

* Thu May 30 2013 Giam Teck Choon <choonrpms@choon.net> - 0.03-1
- Update plugin-check-helo.html
- Update README
- Add match_ipv4 function, implement $HELO_CHECK_REMOTEIP and
  $HELO_CHECK_REMOTEIP_MATCH
- Add init_HostDNSIP function, redo struct HostDNSIP and free_HostDNSIP
  function
- Remove a space
- Implement support environment variable $HELO_CHECK_VERBOSE

* Sat May 25 2013 Giam Teck Choon <choonrpms@choon.net> - 0.02-1
- Add define macro MAX_DNSIP_RECORDS default to 10 if not define and update
  function check_hostname to have this limit

* Fri May 24 2013 Giam Teck Choon <choonrpms@choon.net> - 0.01-1
- Initial Release
